# Copyright (c) 2014 Dave Love, Liverpool University
# Copyright (c) 2018 Dave Love, University of Manchester
# Licence: MIT, per Fedora policy

%global packname  pbdBASE
%global rlibdir	 %{_libdir}/R/library
%global cranver %(echo %version | awk -F'[.]' '{print $1"."$2"-"$3}')
# Use github source if more recent than CRAN
%global github 0
%if 0
%{?el7:%global three 3}
%endif

Name:		  R-%{packname}
Version:	  0.5.3
Release:	  2%{?dist}
Summary:	  Programming with Big Data -- Base Wrappers for Distributed Matrices
License:	  MPLv2.0
URL:		  http://r-pbd.org/
%if 0%{?github}
Source0:          https://github.com/RBigData/%packname/archive/v%cranver/%{packname}-%version.tar.gz
%else
Source0:	  http://cran.r-project.org/src/contrib/%{packname}_%(echo %version | awk -F'\\.' '$4=="" {print $1"."$2"-"$3} $4!="" {print $1"."$2"-"$3"."$4}').tar.gz
%endif
# Required for doc, but not packaged as far as I can tell
Source1:	  http://mirrors.ctan.org/macros/latex/contrib/tocbibind.zip
Requires:	  R-pbdSLAP%{?three-:openmpi3}%{?_isa} >= 0.2.1
BuildRequires:	  R-devel tex(latex) unzip
BuildRequires:	  R-pbdSLAP%{?three-:openmpi3} >= 0.2.1 openmpi%{?three}-devel
BuildRequires:	  scalapack-openmpi%{?three}-devel
# Fixme:  See pbdSLAP
BuildRequires:	  blacs-openmpi%{?three}-devel
BuildRequires:    openblas-devel texlive-lastpage
BuildRequires:	  texlive-multirow


# See R-pbdMPI spec
%global __requires_exclude %{?__requires_exclude:__requires_exclude|}^libmpi|^libscalapack|^libblacs

%global desc \
pbdBASE gives higher packages, like pbdDMAT, access to low-level scalable\
Fortran routines.  The package consists of a set of ScaLAPACK wrappers, as\
well as a host of new C and Fortran code.

%description
%desc

%if 0%{?three}
%package openmpi3
Summary:	  Programming with Big Data -- Base Wrappers for Distributed Matrices
Conflicts:	  %name

%description openmpi3
%desc
%endif

%prep
%setup -q -c -n %{packname}
unzip %SOURCE1
cd tocbibind
latex tocbibind.ins


%build
%if 0%{?github}
# Unfortunately we need to build initially at least to get DESCRIPTION
# into a suitable form to pass check and then install from that, which
# unfortunately builds again, though it's quite fast.
%if 0%{?three}
%_openmpi3_load
%else
%_openmpi_load
%endif
TEXINPUTS=.:$(pwd)/tocbibind: \
R CMD build %{packname}*
tar fx %{packname}*.tar.gz
%endif

%install
mkdir -p %{buildroot}%{rlibdir}
%if 0%{?three}
%_openmpi3_load
%else
%_openmpi_load
%endif
OMPI_MCA_rmaps_base_oversubscribe=1 OMPI_MCA_orte_rsh_agent=/bin/false \
TEXINPUTS=.:$(pwd)/tocbibind: \
R CMD INSTALL -l %{buildroot}%{rlibdir} %{packname}
test -d %{packname}/src && (cd %{packname}/src; rm -f *.o *.so)
rm -f %{buildroot}%{rlibdir}/R.css

%check
%if 0%{?three}
%_openmpi3_load
%else
%_openmpi_load
%endif
OMPI_MCA_rmaps_base_oversubscribe=1 OMPI_MCA_orte_rsh_agent=/bin/false \
TEXINPUTS=.:$(pwd)/tocbibind: \
R CMD check %{packname}


%files %{?three:openmpi3}
%dir %{rlibdir}/%{packname}
%license pbdBASE/COPYING
%doc %{rlibdir}/%{packname}/doc
%doc %{rlibdir}/%{packname}/html
%{rlibdir}/%{packname}/DESCRIPTION
%doc %{rlibdir}/%{packname}/CITATION
%{rlibdir}/%{packname}/help
%doc %{rlibdir}/%{packname}/RNACI
%{rlibdir}/%{packname}/INDEX
%{rlibdir}/%{packname}/NAMESPACE
%{rlibdir}/%{packname}/Meta
%{rlibdir}/%{packname}/R
%{rlibdir}/%{packname}/etc
%{rlibdir}/%{packname}/libs


%changelog
* Tue Jul 20 2021 Dave Love <loveshack@fedoraproject.org> - 0.5.3-2
- BR R-devel again

* Mon May 24 2021 Dave Love <loveshack@fedoraproject.org> - 0.5.3-1
- New version
- Modify Source0

* Fri Aug 21 2020 Dave Love <loveshack@fedoraproject.org> - 0.5.0-4
- BR R-core-devel, not R-devel

* Sun Apr 28 2019 Dave Love <loveshack@fedoraproject.org> - 0.5.0-3
- Maybe use openmpi3 on el7

* Tue Apr 23 2019 Dave Love <loveshack@fedoraproject.org> - 0.5.0-2
- Rebuild for current R version

* Tue May  8 2018 Dave Love <loveshack@fedoraproject.org> - 0.5.0-1
- New version (corresponding to pbdR 1.0-1 release)
- Fix up to get check passing with github source
- Fix some erroneous %%doc

* Tue May  8 2018 Dave Love <loveshack@fedoraproject.org> - 0.4.5.1-1
- New version

* Tue Nov 15 2016 Dave Love <loveshack@fedoraproject.org> - 0.4.5-3
- Bump for copr problems

* Mon Nov 14 2016 Dave Love <loveshack@fedoraproject.org> - 0.4.5-2
- Install license file
- Spec tidying
- BR tex(latex) again for fedora-review
- Reinstate requires filtering

* Sun Nov 13 2016 Dave Love <loveshack@fedoraproject.org> - 0.4.5-1
- New version

* Mon Aug 15 2016 Dave Love <loveshack@fedoraproject.org> - 0.4.3-2
- Remove el5-isms from spec
- Fix requires, like pbdMPI

* Tue Feb 23 2016 Dave Love <loveshack@fedoraproject.org> - 0.4.3-1
- New version
- Don't BR latex

* Tue May 13 2014 Dave Love <d.love@liverpool.ac.uk> 0.2.3-1
- initial package for Fedora
